@@ -4,16 +4,16 @@ void Alternatives::glob(string dir, GlobContext &context)
 try
 {
     for_each(d_command.begin(), d_command.end(),    // add */ to each cmd arg
-            FnWrap1c<string const &, string &>(addPath, dir));
+                        FnWrap::unary(addPath, dir));
 
     dir.resize(dir.length() - 1);                   // remove trailing /
 
-    msg() << "Passing `" << dir << "' to glob" << info;
+    imsg << "Passing `" << dir << "' to glob" << endl;
 
     Glob glob(dir, Glob::NOSORT, Glob::DEFAULT);    // find matching elements
 
     for_each(glob.begin(), glob.end(),              // accept unique dirs.
-             FnWrap1c<char const *, GlobContext &>(globFilter, context));
+                         FnWrap::unary(globFilter, context));
 }
 catch (Errno const &err)      // to catch the exception from glob
 {}
